.. Note: This file is auto-generated using generate_credits.py

.. _credits:

*******
Credits
*******


Matplotlib was written by John D. Hunter, with contributions from an
ever-increasing number of users and developers.  The current lead developer is
Thomas A. Caswell, who is assisted by many `active developers
<https://www.openhub.net/p/matplotlib/contributors>`_.
Please also see our instructions on :doc:`/citing`.

The following is a list of contributors extracted from the
git revision control history of the project:

4over7,
816-8055,
Aaron Boushley,
Aashil Patel,
AbdealiJK,
Abhinav Sagar,
Abhinuv Nitin Pitale,
Acanthostega,
Adam,
Adam Ginsburg,
Adam Gomaa,
Adam Heck,
Adam J. Stewart,
Adam Ortiz,
Adam Paszke,
Adam Ruszkowski,
Adam Williamson,
Adrian Price-Whelan,
Adrien Chardon,
Adrien F. Vincent,
Ahmet Bakan,
Akshay Nair,
Alan Bernstein,
Alan Du,
Alberto,
Alejandro Dubrovsky,
Aleksey Bilogur,
Alex C. Szatmary,
Alex Loew,
Alex Rothberg,
Alex Rudy,
AlexCav,
Alexander Buchkovsky,
Alexander Harnisch,
Alexander Rudy,
Alexander Taylor,
Alexei Colin,
Alexis Bienvenüe,
Ali Mehdi,
Ali Uneri,
Alistair Muldal,
Allan Haldane,
Allen Downey,
Alon Hershenhorn,
Alvaro Sanchez,
Amit Aronovitch,
Amy,
Amy Roberts,
AmyTeegarden,
AndersonDaniel,
Andras Deak,
Andrea Bedini,
Andreas Gustafsson,
Andreas Hilboll,
Andreas Mayer,
Andreas Mueller,
Andreas Wallner,
Andrew Dawson,
Andrew Merrill,
Andrew Nelson,
Andrew Straw,
Andy Mastbaum,
Andy Zhu,
Ankur Dedania,
Anthony Scopatz,
Anton Akhmerov,
Antony Lee,
Anubhav Shrimal,
Ao Liu (frankliuao),
Ardie Orden,
Arie,
Ariel Hernán Curiale,
Arnaud Gardelein,
Arpad Horvath,
Arthur Paulino,
Arvind,
Aseem Bansal,
Ashley Whetter,
Atharva Khare,
Avinash Sharma,
Ayappan P,
BHT,
BTWS,
Bas van Schaik,
Bastian Bechtold,
Behram Mistree,
Ben,
Ben Cohen,
Ben Gamari,
Ben Keller,
Ben Root,
Benedikt Daurer,
Benjamin Bengfort,
Benjamin Berg,
Benjamin Congdon,
Benjamin Reedlunn,
Bernhard M. Wiedemann,
Bharat123rox,
Bianca Gibson,
Binglin Chang,
Bingyao Liu,
Björn Dahlgren,
Blaise Thompson,
Boaz Mohar,
Bradley M. Froehle,
Brandon Liu,
Brendan Zhang,
Brennan Magee,
Brett Cannon,
Brett Graham,
Brian Mattern,
Brian McLaughlin,
Brigitta Sipocz,
Bruno Beltran,
Bruno Pagani,
Bruno Zohreh,
CJ Carey,
Cameron Bates,
Cameron Davidson-Pilon,
Cameron Fackler,
Carissa Brittain,
Carl Michal,
Carsten Schelp,
Carwyn Pelley,
Casey Webster,
Casper van der Wel,
Charles Moad,
Charles Ruan,
Chen Karako,
Cho Yin Yong,
Chris,
Chris Barnes,
Chris Beaumont,
Chris G,
Chris Holdgraf,
Chris Zimmerman,
Christer Jensen,
Christian Brodbeck,
Christian Brueffer,
Christian Stade-Schuldt,
Christoph Dann,
Christoph Deil,
Christoph Gohlke,
Christoph Hoffmann,
Christoph Pohl,
Christoph Reiter,
Christopher Bradshaw,
Cimarron Mittelsteadt,
Clemens Brunner,
Cody Scot,
Colin,
Colin Carroll,
Cong Ma,
Conner R. Phillips,
Corey Farwell,
Craig Citro,
Craig M,
Craig Tenney,
DaCoEx,
Dakota Blair,
Damian,
Damon McDougall,
Dan Hickstein,
Dana,
Daniel C. Marcu,
Daniel Hyams,
Daniel Laidig,
Daniel O'Connor,
DanielMatu,
Daniele Nicolodi,
Danny Hermes,
Dara Adib,
Darren Dale,
DaveL17,
David A,
David Anderson,
David Chudzicki,
David Haberthür,
David Huard,
David Kaplan,
David Kent,
David Kua,
David Stansby,
David Trémouilles,
Dean Malmgren,
Deng Tian,
Derek Kim,
Derek Tropf,
Devashish Deshpande,
Diego Mora Cespedes,
Dietmar Schwertberger,
Dietrich Brunn,
Divyam Madaan,
Dmitry Lupyan,
Dmitry Mottl,
Dmitry Shachnev,
Dominik Schmidt,
DonaldSeo,
Dora Fraeman Caswell,
DoriekeMG,
Dorota Jarecka,
Doug Blank,
Drew J. Sonne,
Duncan Macleod,
Dylan Evans,
E. G. Patrick Bos,
Edin Salkovic,
Edoardo Pizzigoni,
Egor Panfilov,
Elan Ernest,
Elena Glassman,
Elias Pipping,
Elijah Schutz,
Elizabeth Seiver,
Elliott Sales de Andrade,
Elvis Stansvik,
Emil Mikulic,
Emlyn Price,
Eric Dill,
Eric Firing,
Eric Larson,
Eric Ma,
Eric O. LEBIGOT (EOL),
Eric Relson,
Eric Wieser,
Erik Bray,
Erik M. Bray,
Erin Pintozzi,
Eugen Beck,
Eugene Yurtsev,
Evan Davey,
Ezra Peisach,
Fabian Kloosterman,
Fabian-Robert Stöter,
Fabien Maussion,
Fabio Zanini,
FedeMiorelli,
Federico Ariza,
Felipe,
Felix,
Felix Kohlgrüber,
Felix Yan,
Fernando Perez,
Filip Dimitrovski,
Filipe Fernandes,
Florencia Noriega,
Florian Le Bourdais,
Florian Rhiem,
Francesco Montesano,
Francis Colas,
Franco Vaccari,
Francoise Provencher,
Frank Sauerburger,
Frank Yu,
François Magimel,
Gabe,
Gabriel Munteanu,
Gal Avineri,
Galen Lynch,
Gauravjeet,
Gaute Hope,
Gazing,
Gellule Xg,
Geoffrey Spear,
Geoffroy Billotey,
Georg Raiser,
Gerald Storer,
Gina,
Giovanni,
Graeme Smecher,
Graham Poulter,
Greg Lucas,
Gregory Ashton,
Gregory R. Lee,
Grillard,
Grégory Lielens,
Guillaume Gay,
Guillermo Breto,
Gustavo Braganca,
Gustavo Goretkin,
HHest,
Hajoon Choi,
Hakan Kucukdereli,
Hanno Rein,
Hans Dembinski,
Hans Meine,
Hans Moritz Günther,
Harnesser,
Harshal Prakash Patankar,
Harshit Patni,
Hassan Kibirige,
Hastings Greer,
Heath Henley,
Heiko Oberdiek,
Helder,
Henning Pohl,
Herbert Kruitbosch,
Holger Peters,
Hubert Holin,
Hugo van Kemenade,
Ian Hincks,
Ian Thomas,
Ida Hjorth,
Ignas Anikevicius (gns_ank),
Ildar Akhmetgaleev,
Ilia Kurenkov,
Ilya Flyamer,
ImSoErgodic,
ImportanceOfBeingErnest,
Inception95,
Ingo Fründ,
Ioannis Filippidis,
Isa Hassen,
Isaac Schwabacher,
Isaac Slavitt,
Ismo Toijala,
J Alammar,
J. Goutin,
Jaap Versteegh,
Jack Kelly,
Jacob McDonald,
Jacobson Okoro,
Jae-Joon Lee,
Jaime Fernandez,
Jake Lee,
Jake Vanderplas,
James A. Bednar,
James Adams,
James Pallister,
James R. Evans,
JamesMakela,
Jamie Nunez,
Jan S. (Milania1),
Jan Schlüter,
Jan Schulz,
Jan-Philip Gehrcke,
Jan-willem De Bleser,
Jarrod Millman,
Jascha Ulrich,
Jason Grout,
Jason King,
Jason Liw Yan Chong,
Jason Miller,
Jason Neal,
Jason Zheng,
Javad,
JayP16,
Jean-Benoist Leger,
Jeff Lutgen,
Jeff Whitaker,
Jeffrey Bingham,
Jeffrey Hokanson @ Loki,
JelsB,
Jens Hedegaard Nielsen,
Jeremy Fix,
Jeremy O'Donoghue,
Jeremy Thurgood,
Jeroonk,
Jessica B. Hamrick,
Jiahao Chen,
Jim Radford,
Jochen Voss,
Jody Klymak,
Joe Kington,
Joel B. Mohler,
Joel Frederico,
Joel Wanner,
Johannes H. Jensen,
Johannes Wienke,
John Hoffman,
John Hunter,
John Vandenberg,
Johnny Gill,
JojoBoulix,
Jon Haitz Legarreta Gorroño,
Jonas Camillus Jeppesen,
Jonathan Waltman,
Jorge Moraleda,
Jorrit Wronski,
Joscha Reimer,
Josef Heinen,
Joseph Albert,
Joseph Fox-Rabinovitz,
Joseph Jon Booker,
Joseph Martinot-Lagarde,
Joshua Taillon,
José Ricardo,
Jouni K. Seppänen,
Joy Bhalla,
Juan Nunez-Iglesias,
Juanjo Bazán,
Julia Sprenger,
Julian Mehne,
Julian Taylor,
Julian V. Modesto,
JulianCienfuegos,
Julien Lhermitte,
Julien Schueller,
Julien Woillez,
Julien-Charles Lévesque,
Jun Tan,
Justin Cai,
Jörg Dietrich,
Kacper Kowalik (Xarthisius),
Kai Muehlbauer,
Kanchana Ranasinghe,
Kanwar245,
Katrin Leinweber,
Katy Huff,
Kayla Ngan,
Keerysanth Sribaskaran,
Ken McIvor,
Kenneth Ma,
Kevin Chan,
Kevin Davies,
Kevin Ji,
Kevin Keating,
Kevin Mader,
Kevin Rose,
Kexuan Sun,
Kieran Ramos,
Kimmo Palin,
Kjartan Myrdal,
Kjell Le,
Klara Gerlei,
Konrad Förstner,
Konstantin Tretyakov,
Kristen M. Thyng,
Kyle Bridgemohansingh,
Kyle Sunden,
Kyler Brown,
Lance Hepler,
Laptop11_ASPP2016,
Larry Bradley,
Laurent Thomas,
Lawrence D'Anna,
Leeonadoh,
Lennart Fricke,
Leo Singer,
Leon Loopik,
Leon Yin,
LevN0,
Levi Kilcher,
Liam Brannigan,
Lion Krischer,
Lionel Miller,
Lodato Luciano,
Lori J,
Loïc Estève,
Loïc Séguin-C,
Luca Verginer,
Luis Pedro Coelho,
Luke Davis,
Maarten Baert,
Maciej Dems,
Magnus Nord,
Maik Riechert,
Majid alDosari,
Maksym P,
Manan,
Manan Kevadiya,
Manish Devgan,
Manuel GOACOLOU,
Manuel Jung,
Manuel Metz,
Manuel Nuno Melo,
Maoz Gelbart,
Marat K,
Marc Abramowitz,
Marcel Martin,
Marco Gorelli,
MarcoGorelli,
Marcos Duarte,
Marek Rudnicki,
Marianne Corvellec,
Marin Gilles,
Mark Harfouche,
Mark Wolf,
Marko Baštovanović,
Markus Roth,
Markus Rothe,
Martin Dengler,
Martin Fitzpatrick,
Martin Spacek,
Martin Teichmann,
Martin Thoma,
Martin Ueding,
Massimo Santini,
Masud Rahman,
Mathieu Duponchelle,
Matt Giuca,
Matt Hancock,
Matt Klein,
Matt Li,
Matt Newville,
Matt Shen,
Matt Terry,
Matthew Bell,
Matthew Brett,
Matthew Emmett,
Matthias Bussonnier,
Matthias Geier,
Matthias Lüthi,
Matthieu Caneill,
MatthieuDartiailh,
Matti Picus,
Matěj Týč,
Max Chen,
Max Humber,
Max Shinn,
Maximilian Albert,
Maximilian Maahn,
Maximilian Nöthe,
Maximilian Trescher,
MeeseeksMachine,
Mellissa Cross,
Mher Kazandjian,
Michael,
Michael Droettboom,
Michael Jancsy,
Michael Sarahan,
Michael Scott Cuthbert,
Michael Seifert,
Michael Welter,
Michaël Defferrard,
Michele Mastropietro,
Michiel de Hoon,
Michka Popoff,
Mike Henninger,
Mike Jarvis,
Mike Kaufman,
Mikhail Korobov,
MinRK,
Mingkai Dong,
Minty Zhang,
MirandaXM,
Miriam Sierig,
Mitar,
Molly Rossow,
Moritz Boehle,
Mudit Surana,
Muhammad Mehdi,
MuhammadFarooq1234,
Mykola Dvornik,
Naoya Kanai,
Nathan Goldbaum,
Nathan Musoke,
Nathaniel M. Beaver,
Neil,
Neil Crighton,
Nelle Varoquaux,
Niall Robinson,
Nic Eggert,
Nicholas Devenish,
Nick Forrington,
Nick Garvey,
Nick Papior,
Nick Pope,
Nick Semenkovich,
Nico Schlömer,
Nicolas Courtemanche,
Nicolas P. Rougier,
Nicolas Pinto,
Nicolas Tessore,
Nik Quibin,
Nikita Kniazev,
Niklas Koep,
Nikolay Vyahhi,
Nils Werner,
Ninad Bhat,
Norbert Nemec,
Norman Fomferra,
O. Castany,
OceanWolf,
Oleg Selivanov,
Olga Botvinnik,
Oliver Natt,
Oliver Willekens,
Olivier,
Om Sitapara,
Omar Chehab,
Oriol Abril,
Orso Meneghini,
Osarumwense,
Pankaj Pandey,
Paramonov Andrey,
Parfenov Sergey,
Pascal Bugnion,
Pastafarianist,
Patrick Chen,
Patrick Feiring,
Patrick Marsh,
Patrick Shriwise,
PatrickFeiring,
Paul,
Paul Barret,
Paul Ganssle,
Paul Gierz,
Paul Hobson,
Paul Hoffman,
Paul Ivanov,
Paul J. Koprowski,
Paul Kirow,
Paul Romano,
Paul Seyfert,
Pauli Virtanen,
Pavel Fedin,
Pavol Juhas,
Per Parker,
Perry Greenfield,
Pete Bachant,
Pete Huang,
Pete Peterson,
Peter Iannucci,
Peter Mackenzie-Helnwein,
Peter Mortensen,
Peter Schutt,
Peter St. John,
Peter Würtz,
Petr Danecek,
Phil Elson,
Phil Ruffwind,
Philippe Pinard,
Pierre Haessig,
Pierre Thibault,
Pierre de Buyl,
Pim Schellart,
Piti Ongmongkolkul,
Po,
Pranav Garg,
Przemysław Dąbek,
Puneeth Chaganti,
QiCuiHub,
Qingpeng "Q.P." Zhang,
RAKOTOARISON Herilalaina,
Ram Rachum,
Ramiro Gómez,
Randy Olson,
Raphael,
Rasmus Diederichsen,
Ratin_Kumar,
Rebecca W Perry,
Reinier Heeres,
Remi Rampin,
Ricardo Mendes,
Riccardo Di Maio,
Richard Gowers,
Richard Hattersley,
Richard Ji-Cathriner,
Richard Trieu,
Ricky,
Rishikesh,
Rob Harrigan,
Robert Johansson,
Robin Dunn,
Robin Neatherway,
Robin Wilson,
Rohan Walker,
Roland Wirth,
Roman Yurchak,
Ronald Hartley-Davies,
RoryIAngus,
Roy Smith,
Rui Lopes,
Russell Owen,
RutgerK,
Ryan,
Ryan Blomberg,
Ryan D'Souza,
Ryan Dale,
Ryan May,
Ryan Morshead,
Ryan Nelson,
RyanPan,
SBCV,
Sairam Pillai,
Saket Choudhary,
Salganos,
Salil Vanvari,
Salinder Sidhu,
Sam Vaughan,
SamSchott,
Sameer D'Costa,
Samesh Lakhotia,
Samson,
Samuel St-Jean,
Sander,
Sandro Tosi,
Scott Howard,
Scott Lasley,
Scott Lawrence,
Scott Stevenson,
Sean Farley,
Sebastian Bullinger,
Sebastian Pinnau,
Sebastian Raschka,
Sebastián Vanrell,
Seraphim Alvanides,
Sergey B Kirpichev,
Sergey Kholodilov,
Sergey Koposov,
Seunghoon Park,
Siddhesh Poyarekar,
Sidharth Bansal,
Silviu Tantos,
Simon Cross,
Simon Gibbons,
Simon Legner,
Skelpdar,
Skipper Seabold,
Slav Basharov,
Snowhite,
SojiroFukuda,
Sourav Singh,
Spencer McIntyre,
Stanley, Simon,
Stefan Lehmann,
Stefan Mitic,
Stefan Pfenninger,
Stefan van der Walt,
Stefano Rivera,
Stephan Erb,
Stephane Raynaud,
Stephen Horst,
Stephen-Chilcote,
Sterling Smith,
Steve Chaplin,
Steve Dower,
Steven G. Johnson,
Steven Munn,
Steven Silvester,
Steven Tilley,
Stuart Mumford,
Tadeo Corradi,
Taehoon Lee,
Takafumi Arakaki,
Takeshi Kanmae,
Tamas Gal,
Tanuj,
Taras Kuzyo,
Ted Drain,
Ted Petrou,
Terence Honles,
Terrence J. Katzenbaer,
Terrence Katzenbaer,
The Gitter Badger,
Thein Oo,
Thomas A Caswell,
Thomas Hisch,
Thomas Kluyver,
Thomas Lake,
Thomas Levine,
Thomas Mansencal,
Thomas Robitaille,
Thomas Spura,
Thomas VINCENT,
Thorsten Liebig,
Tian Xia,
Till Hoffmann,
Till Stensitzki,
Tim Hoffmann,
Timo Vanwynsberghe,
Tobia De Koninck,
Tobias Froehlich,
Tobias Hoppe,
Tobias Megies,
Todd Jennings,
Todd Miller,
Tom,
Tom Augspurger,
Tom Dupré la Tour,
Tom Flannaghan,
Tomas Kazmar,
Tony S Yu,
Tor Colvin,
Travis Oliphant,
Trevor Bekolay,
Trish Gillett-Kawamoto,
Truong Pham,
Tuan Dung Tran,
Tyler Makaro,
Tyrone Xiong,
Ulrich Dobramysl,
Umair Idris,
V. Armando Solé,
V. R,
Vadim Markovtsev,
Valentin Haenel,
Valentin Schmidt,
Vedant Nanda,
Venkada,
Vidur Satija,
Viktor Kerkez,
Vincent L.M. Mazoyer,
Viraj Mohile,
Vitaly Buka,
Vlad Seghete,
Víctor Terrón,
Víctor Zabalza,
WANG Aiyong,
Warren Weckesser,
Wen Li,
Wendell Smith,
Werner F Bruhin,
Wes Campaigne,
Wieland Hoffmann,
Will Handley,
Will Silva,
William Granados,
William Mallard,
William Manley,
Wouter Overmeire,
Xiaowen Tang,
Xufeng Wang,
Yann Tambouret,
Yao-Yuan Mao,
Yaron de Leeuw,
Yu Feng,
Yue Zhihan,
Yunfei Yang,
Yuri D'Elia,
Yuval Langer,
Yuxin Wu,
Yuya,
Zac Hatfield-Dodds,
Zach Pincus,
Zair Mubashar,
Zbigniew Jędrzejewski-Szmek,
Zhili (Jerry) Pan,
Zulko,
ahed87,
akrherz,
alcinos,
alex,
alvarosg,
andrzejnovak,
aneda,
anykraus,
aparamon,
apodemus,
arokem,
as691454,
aseagram,
ash13,
aszilagyi,
azure-pipelines[bot],
bblay,
bduick,
bev-a-tron,
blackw1ng,
blah blah,
brut,
btang02,
buefox,
burrbull,
butterw,
cammil,
captainwhippet,
cclauss,
ch3rn0v,
chadawagner,
chaoyi1,
chebee7i,
chelseatroy,
chuanzhu xu,
cknd,
cldssty,
clintval,
dabana,
dahlbaek,
danielballan,
daronjp,
davidovitch,
daydreamt,
deeenes,
deepyaman,
djdt,
dlmccaffrey,
domspad,
donald,
donchanee,
drevicko,
e-q,
elpres,
endolith,
esvhd,
et2010,
fardal,
ffteja,
fgb,
fibersnet,
fourpoints,
fredrik-1,
frenchwr,
fuzzythecat,
fvgoto,
gcallah,
gitj,
gluap,
gnaggnoyil,
goir,
goldstarwebs,
greg-roper,
gregorybchris,
gwin-zegal,
hannah,
helmiriawan,
henryhu123,
hugadams,
ilivni,
insertroar,
itziakos,
jacob-on-github,
jb-leger,
jbbrokaw,
jbhopkins,
jdollichon,
jerrylui803,
jess,
jfbu,
jhelie,
jli,
joaonsg,
joelostblom,
jonchar,
juan.gonzalez,
kcrisman,
keithbriggs,
kelsiegr,
khyox,
kikocorreoso,
klaus,
klonuo,
kolibril13,
kramer65,
krishna katyal,
ksafran,
kshramt,
lboogaard,
legitz7,
lepuchi,
lichri12,
limtaesu,
lspvic,
luftek,
luz.paz,
lzkelley,
mamrehn,
marky,
masamson,
mbyt,
mcelrath,
mcquin,
mdipierro,
mikhailov,
miquelastein,
mitch,
mlub,
mobando,
mromanie,
muahah,
myyc,
nathan78906,
navdeep rana,
nbrunett,
nemanja,
neok-m4700,
nepix32,
nickystringer,
njwhite,
nmartensen,
nwin,
ob,
pdubcali,
pibion,
pkienzle,
productivememberofsociety666,
profholzer,
pupssman,
rahiel,
ranjanm,
rebot,
rhoef,
rsnape,
ruin,
rvhbooth,
s0vereign,
s9w,
saksmito,
scls19fr,
scott-vsi,
sdementen,
serv-inc,
settheory,
sfroid,
shaunwbell,
simon-kraeusel,
simonpf,
sindunuragarp,
smheidrich,
sohero,
spiessbuerger,
stahlous,
stone,
stonebig,
switham,
sxntxn,
syngron,
teresy,
thoo,
thuvejan,
tmdavison,
tomoemon,
tonyyli,
torfbolt,
u55,
ugurthemaster,
ultra-andy,
vab9,
vbr,
vishalBindal,
vraelvrangr,
watkinrt,
woclass,
xbtsw,
xuanyuansen,
y1thof,
yeo,
zhangeugenia,
zhoubecky,
Élie Gouzien,
Андрей Парамонов

Some earlier contributors not included above are (with apologies
to any we have missed):

Charles Twardy,
Gary Ruben,
John Gill,
David Moore,
Paul Barrett,
Jared Wahlstrand,
Jim Benson,
Paul Mcguire,
Andrew Dalke,
Nadia Dencheva,
Baptiste Carvello,
Sigve Tjoraand,
Ted Drain,
James Amundson,
Daishi Harada,
Nicolas Young,
Paul Kienzle,
John Porter,
and Jonathon Taylor.

Thanks to Tony Yu for the original logo design.

We also thank all who have reported bugs, commented on
proposed changes, or otherwise contributed to Matplotlib's
development and usefulness.
